knots.ewcdf: Jump Points of an Empirical Weighted Cumulative Distribution...

View source: R/ewcdf.R

knots.ewcdfR Documentation

Jump Points of an Empirical Weighted Cumulative Distribution Function

Description

Extract the knots (jump points) of an empirical cumulative distribution function.

Usage

 ## S3 method for class 'ewcdf'
knots(Fn, ...)
 ## S3 method for class 'ecdf'
knots(Fn, ...)

Arguments

Fn

An empirical cumulative distribution function (object of class "ecdf" or "ewcdf").

...

Ignored.

Details

The function knots is generic.

The function knots.ecdf is the method for the class "ecdf" of empirical cumulative distribution functions; objects of this class are created by ecdf).

The function knots.ewcdf is the method for the class "ewcdf" of empirical weighted cumulative distribution functions. Objects of class "ewcdf" are created by ewcdf.

The jump points (locations of increments) of the function Fn will be returned as a numeric vector.

Value

Numeric vector.

Author(s)

\spatstatAuthors

.

See Also

ecdf, ewcdf, quantile.ewcdf

Examples

   x <- c(1, 2, 5)
   w <- runif(3)
   e <- ewcdf(x,w)
   knots(e)

spatstat.univar documentation built on May 18, 2026, 9:06 a.m.